# generates all possible pairs of color stimuli
# for the prosem color experiment.
# The csv file with the stimuli are read in
# and a new csv file with the pairs is created

rm(list = ls())							# clear the workspace

# first make the csv files that contain the stimiuli
fno <- "color_stimuli.csv"				# ouput file name
n.hue <- 6								# number of hues
n.sat <- 2								# number of saturations
n.val <- 1								# number of values

hue.inc <- 360 / n.hue
hues <- c(0:(n.hue - 1)) * hue.inc
sats <- c(1.0, 0.3)
vals <- c(1.0)

index <- 0
for (s in sats) {
	for (h in hues) {
		for (v in vals) {
			index <- index + 1
			if (!exists("df0")) {
				df0 <- data.frame(index = index,
					color = paste("c", sprintf("%02d", index), sep = ""), hsv = paste("[", h, ",", s, ",", v,"]", sep = ""))
			} else {
				dt0 <- data.frame(index = index,
					color = paste("c", sprintf("%02d", index), sep = ""), hsv = paste("[", h, ",", s, ",", v,"]", sep = ""))
				df0 <- rbind(df0, dt0)
			}
		}
	}
}
# write out csv file of the stimuli
write.csv(df0, fno, row.names = FALSE)

fni <- fno								# input file name
fno <- "color_pairwise_stimuli.csv"		# output file name
df0 <- read.csv(fni, header = TRUE)
nstim <- nrow(df0)						# number of stimuli


# generate all the pairs
# which is of two pairs is the left one is chosen randomly if
# pos.prob is set to 0.5. If set to 1.0 than the lower stimulus
# will be first.
# pos.prob <- 1.0		# outer loop stimulus (j) will always be on the left
pos.prob <- 0.5			# position of stimulus pairs is random
nm1 <- nstim - 1
pair_no <- 0
for (i in 1:nm1) {
		ip1 <- i + 1
	for (j in ip1:nstim){
		pair_no <- pair_no + 1
		if (runif(1) > pos.prob){
			i1 <- j
			i2 <- i
		} else {
			i1 <- i
			i2 <- j
		}

		if (!exists("df1")){
			df1 <- data.frame(pair_no = pair_no,
							  index_lft = df0[i1, "index"], color_lft = df0[i1, "color"], hsv_lft = df0[i1, "hsv"],
							  index_rgt = df0[i2, "index"], color_rgt = df0[i2, "color"], hsv_rgt = df0[i2, "hsv"])
		}
		else {
			dt1 <- data.frame(pair_no = pair_no,
							  index_lft = df0[i1, "index"], color_lft = df0[i1, "color"], hsv_lft = df0[i1, "hsv"],
							  index_rgt = df0[i2, "index"], color_rgt = df0[i2, "color"], hsv_rgt = df0[i2, "hsv"])
			df1 <- rbind(df1, dt1)
		}
	}
}

# write out csv file of the pairs
write.csv(df1, fno, row.names = FALSE)